# Changelog

## Unreleased

## Version 0.16b0

Released 2020-11-25

- Update protobuf versions
  ([#1356](https://github.com/open-telemetry/opentelemetry-python/pull/1356))

## Version 0.13b0

Released 2020-09-17

- Drop support for Python 3.4'
  ([#1099](https://github.com/open-telemetry/opentelemetry-python/pull/1099))

## Version 0.12b0

Released 2020-08-14

- Change package name to opentelemetry-exporter-opencensus
  ([#953](https://github.com/open-telemetry/opentelemetry-python/pull/953))
- Send start_timestamp and convert labels to strings
  ([#937](https://github.com/open-telemetry/opentelemetry-python/pull/937))

## 0.8b0

Released 2020-05-27

- Rename otcollector to opencensus
  ([#695](https://github.com/open-telemetry/opentelemetry-python/pull/695))

## 0.5b0

Released 2020-03-16

- Initial release.
